<?php



/**
 * This class represents a directory, it needs you to give it the path
 * you can get it to
 * - list the files under that directory
 * - check that it exists and is a directory
 * - make the directory, if the parent directory exists
 **/

class Dir
{
  // PUBLIC

  public function __construct( $s_path = '' ) { $this->SetPath( $s_path ); }

  public function SetPath( $s_path ) { $this->path = $s_path; }
  public function GetPath() { return $this->path; }

  public function Create() { mkdir( $this->path ); }
  public function Remove() { rmdir( $this->path ); }

  public function IsDir() { return is_dir($this->path); }

  public function ListFiles()
  {
    $file_list = Array();

    $dirhandler = opendir( $this->path );
    if( $dirhandler !== false )
    {
      while( ( $next_file = readdir( $dirhandler ) ) !== false )
      {
	$file_list[] = $next_file;
      }
      closedir( $dirhandler );
    }

    return $file_list;
  }

  // PRIVATE

  private $path;
};



function TestDir()
{
  // get a temporary filename
  // test that there is no dir with that name
  // create a directory using that tmpfile name
  // test that the new directory exists as a directory
  // create a test file in the directory
  // test that the test file was created correctly
  // get the list of files in the directory
  // test that the list simply contains the test file
  // delete the test file
  // remove the directory
  // test that the directory no longer exists

  $tmp_file = new File();
  $tmp_file->SetFullPath( tempnam('','') );
  $tmp_file->Remove();
  
  $dir = new Dir();
  $dir->SetPath( $tmp_file->GetFullPath() );
  
  PerformTest( 'Testing temp file doesnt exist',
	       ( !$tmp_file->Exists() ),
	       'The file created by tempnam still exists' );
  
  PerformTest( 'Testing temp dir does not exist',
	       ( !$dir->IsDir() ),
	       'The test directory exists for some reason ' . $dir->GetPath() );
  
  $dir->Create();
  
  PerformTest( 'Test that we created the directory successfully',
	       ( $dir->IsDir() ),
	       'Failed to create the directory ' . $dir->GetPath() );
  
  $test_file = new File( $dir->GetPath(), 'testing' );
  $test_file->Create();
  PerformTest( 'Testing we can create a file in the new directory',
	       ( $test_file->Exists() ),
	       'Failed to create file called testing in directory' . $dir->GetPath() );
  
  $all_files = $dir->ListFiles();
  PerformTest( 'Testing we have the correct number of files from the directory',
	       ( count($all_files) == 3 ),
	       'Wrong number of files listed in directory ' . count($all_files) );
  
  PerformTest( 'Testing the file we want is listed correctly',
	       ( $all_files[1] == 'testing' ),
	       'The file "testing" is not there' );
  
  $test_file->Remove();
  PerformTest( 'testing we removed the test file successfully',
	       ( !$test_file->Exists() ),
	       'Failed to remove the test file from out test directory' );
  
  $dir->Remove();
  
  PerformTest( 'Test that we can remove the directoroy',
	       ( !$dir->IsDir() ),
	       'Failed to remove the directory ' . $dir->GetPath() );
}





?>