<?php



/**
 * This simple class represents a path/filename pair. Not a very usefull class
 * but it does ensure both components are initialized to '' and we can get
 * either component on its own or both together.
 **/

class File
{
  // PUBLIC

    public function __construct( $s_path = '', $s_file = '' )
    {
      $this->path = $s_path;
      $this->filename = $s_file;
    }

    public function SetFilename( $s_filename ) { $this->filename = $s_filename; }
    public function SetPath( $s_path ) { $this->path = $s_path; }

    public function GetFilename() { return $this->filename; }
    public function GetPath() { return $this->path; }

    public function GetFullPath() { return "$this->path/$this->filename"; }
    public function SetFullPath( $s_full_path )
    {
      $this->path = substr( $s_full_path, 0, strrpos( $s_full_path, '/' ) );
      $this->filename = substr( $s_full_path, strrpos( $s_full_path, '/' ) + 1 );
    }

    public function IsDir() { return is_dir( $this->GetFullPath() ); }
    public function IsFile() { return is_file( $this->GetFullPath() ); }
    public function IsLink() { return is_link( $this->GetFullPath() ); }

    public function Exists() { return file_exists( $this->GetFullPath() ); }

    public function Create() { touch( $this->GetFullPath() ); }

    public function Remove() { unlink( $this->GetFullPath() ); }

  // PRIVATE

    private $filename;
    private $path;
};


function TestFile()
{
  $tmp_name = tempnam( '', 'FileTest');
  $tmp_dir = substr( $tmp_name, 0, strrpos( $tmp_name, '/' ) );
  $tmp_file = substr( $tmp_name, strrpos( $tmp_name, '/' ) + 1 );

  $f1 = new File();

  $f1->SetPath( $tmp_dir );
  PerformTest( 'Testing path Getter/Setters',
	       ($f1->GetPath() == $tmp_dir),
	       'Path retreived does not match path entered' );

  $f1->SetFilename( $tmp_file );
  PerformTest( 'Testing filename Getter/Setter',
	       ($f1->GetFilename() == $tmp_file ),
	       'Filename retreived does not match filenamed entered' );

  PerformTest( 'Testing GetFullPath function',
	       ($f1->GetFullPath() == $tmp_name),
	       'Full path returned does not match the path and filename set' );
  
  $f1->SetFullPath( $tmp_name );
  PerformTest( 'Testing SetFullPath breaks up correctly',
	       ($f1->GetPath() == $tmp_dir),
	       'The path was not extracted from the full path correctly' );

  PerformTest( 'Testing SetFullPath separates filename correctly',
	       ($f1->GetFilename() == $tmp_file),
	       'The filename was not extracted from the full path correctly' );
  
  PerformTest( 'Testing tempnam created the file',
	       ($f1->Exists()),
	       'The file specified doesnt exist' . $f1->GetFullPath() );

  PerformTest( 'Testing directory test',
	       (!$f1->IsDir()),
	       'The file specified is a directory ???' );

  PerformTest( 'Testing link test',
	       (!$f1->IsLink()),
	       'The file specified is a link ???' );

  $f1->Remove();

  PerformTest( 'Testing file deletion',
	       ( !$f1->Exists() ),
	       'The file still exists' . $f1->GetFullPath() );

  $f1->Create();

  PerformTest( 'Testing file creation',
	       ( $f1->Exists() ),
	       'The file wasnt created' . $f1->GetFullPath() );
}

?>